summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorstefanf <stefanf@FreeBSD.org>2005-08-31 19:44:40 +0000
committerstefanf <stefanf@FreeBSD.org>2005-08-31 19:44:40 +0000
commit991cce17d6fc922ae716ac677575385a85ef761e (patch)
tree3dea1910c32c80b329e9de39aff4e37b9005d0df
parenta65c888f9931c9ca8af0cab1005eca5056cc0614 (diff)
downloadFreeBSD-src-991cce17d6fc922ae716ac677575385a85ef761e.zip
FreeBSD-src-991cce17d6fc922ae716ac677575385a85ef761e.tar.gz
Rename the variable `inline' to `inline_size'.
-rw-r--r--usr.bin/rpcgen/Makefile5
-rw-r--r--usr.bin/rpcgen/rpc_cout.c16
-rw-r--r--usr.bin/rpcgen/rpc_main.c4
-rw-r--r--usr.bin/rpcgen/rpc_util.h2
4 files changed, 11 insertions, 16 deletions
diff --git a/usr.bin/rpcgen/Makefile b/usr.bin/rpcgen/Makefile
index d01e863..c298820 100644
--- a/usr.bin/rpcgen/Makefile
+++ b/usr.bin/rpcgen/Makefile
@@ -5,10 +5,5 @@ SRCS= rpc_main.c rpc_clntout.c rpc_cout.c rpc_hout.c rpc_parse.c \
rpc_sample.c rpc_scan.c rpc_svcout.c rpc_tblout.c rpc_util.c
WARNS?= 2
-#
-# This is a kludge to work around the fact that this program
-# uses 'inline' as a variable name.
-#
-CFLAGS+=-Dinline=rpcgen_inline
.include <bsd.prog.mk>
diff --git a/usr.bin/rpcgen/rpc_main.c b/usr.bin/rpcgen/rpc_main.c
index 7d54d23..5e59848 100644
--- a/usr.bin/rpcgen/rpc_main.c
+++ b/usr.bin/rpcgen/rpc_main.c
@@ -128,7 +128,7 @@ int mtflag = 0; /* Support for MT */
#define INLINE 0
/* length at which to start doing an inline */
-int inline = INLINE;
+int inline_size = INLINE;
/*
* Length at which to start doing an inline. INLINE = default
* if 0, no xdr_inline code
@@ -1178,7 +1178,7 @@ parseargs(argc, argv, cmd)
if (++i == argc) {
return (0);
}
- inline = atoi(argv[i]);
+ inline_size = atoi(argv[i]);
goto nextarg;
case 'n':
case 'o':
diff --git a/usr.bin/rpcgen/rpc_util.h b/usr.bin/rpcgen/rpc_util.h
index 7343827..ce21d4e 100644
--- a/usr.bin/rpcgen/rpc_util.h
+++ b/usr.bin/rpcgen/rpc_util.h
@@ -134,7 +134,7 @@ extern int newstyle;
extern int Cflag; /* ANSI-C/C++ flag */
extern int CCflag; /* C++ flag */
extern int tirpcflag; /* flag for generating tirpc code */
-extern int inline; /* if this is 0, then do not generate inline code */
+extern int inline_size; /* if this is 0, then do not generate inline code */
extern int mtflag;
/*
OpenPOWER on IntegriCloud
diff --git a/usr.bin/rpcgen/rpc_cout.c b/usr.bin/rpcgen/rpc_cout.c
index f1b288a..f8a18d4 100644
--- a/usr.bin/rpcgen/rpc_cout.c
+++ b/usr.bin/rpcgen/rpc_cout.c
@@ -161,7 +161,7 @@ print_header(def)
def->def.ty.rel));
/* Now add Inline support */
- if (inline == 0)
+ if (inline_size == 0)
return;
/* May cause lint to complain. but ... */
f_print(fout, "\tregister long *buf;\n\n");
@@ -465,10 +465,10 @@ int flag;
}
} else {
if (i > 0) {
- if (sizestr == NULL && size < inline){
+ if (sizestr == NULL && size < inline_size){
/*
* don't expand into inline code
- * if size < inline
+ * if size < inline_size
*/
while (cur != dl){
print_stat(indent + 1, &cur->decl);
@@ -522,8 +522,8 @@ int flag;
}
if (i > 0) {
- if (sizestr == NULL && size < inline){
- /* don't expand into inline code if size < inline */
+ if (sizestr == NULL && size < inline_size){
+ /* don't expand into inline code if size < inline_size */
while (cur != dl){
print_stat(indent + 1, &cur->decl);
cur = cur->next;
@@ -570,7 +570,7 @@ emit_struct(def)
bas_type *ptr;
int can_inline;
- if (inline == 0) {
+ if (inline_size == 0) {
/* No xdr_inlining at all */
for (dl = def->def.st.decls; dl != NULL; dl = dl->next)
print_stat(1, &dl->decl);
@@ -600,13 +600,13 @@ emit_struct(def)
break; /* can be inlined */
}
} else {
- if (size >= inline){
+ if (size >= inline_size){
can_inline = 1;
break; /* can be inlined */
}
size = 0;
}
- if (size >= inline)
+ if (size >= inline_size)
can_inline = 1;
if (can_inline == 0){ /* can not inline, drop back to old mode */